@@ -1,4 +1,12 @@
+import platform
+import time
+
+from memory_profiler import memory_usage
+from pytest import mark
+
 from wand.color import Color
+from wand.compat import xrange
+from wand.version import MAGICK_VERSION_INFO
 
 
 def test_equals():
@@ -90,3 +98,19 @@ def test_alpha_int8():
 def test_string():
     assert Color('black').string in ('rgb(0,0,0)', 'srgb(0,0,0)')
     assert str(Color('black')) in ('rgb(0,0,0)', 'srgb(0,0,0)')
+
+
+def color_memory_leak():
+    for i in xrange(5000):
+        with Color('orange'):
+            pass
+    time.sleep(0.02)
+
+
+@mark.skipif('MAGICK_VERSION_INFO <= (6, 6, 9, 7)')
+def test_memory_leak():
+    """https://github.com/dahlia/wand/pull/127"""
+    consumes = memory_usage((color_memory_leak, (), {}))
+    vm = platform.python_implementation()
+    minimum = 15.0 if vm == 'PyPy' else 1.0  # FIXME
+    assert consumes[-1] - consumes[0] <= minimum
