@@ -184,6 +184,20 @@ def test_save_to_file(fx_asset):
         with Image(file=buffer) as saved:
             assert saved.size == (402, 599)
     buffer.close()
+    
+    
+def test_save_full_animated_gif_to_file(fx_asset):
+    """Save all frames of an animated to a Python file object."""
+    temp_filename = os.path.join(tempfile.mkdtemp(), 'savetest.gif')
+    orig_filename = str(fx_asset.join('nocomments.gif'))
+    with open(temp_filename, 'w+b') as fp:
+        with Image(filename= orig_filename) as orig:
+            orig.save(file= fp)
+    assert os.path.isfile(temp_filename)
+    with Image(filename= orig_filename) as orig:
+        with Image(filename= temp_filename) as temp:
+            assert len(orig.sequence) == len(temp.sequence)
+    os.remove(temp_filename)
 
 
 def test_save_error(fx_asset):
@@ -280,6 +294,19 @@ def test_set_units(fx_asset):
         assert img.units == "pixelspercentimeter"
 
 
+def test_get_colorspace(fx_asset):
+    """Gets the image colorspace"""
+    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+        assert img.colorspace.endswith('rgb')
+
+
+def test_set_colorspace(fx_asset):
+    """Sets the image colorspace"""
+    with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
+        img.colorspace = 'cmyk'
+        assert img.colorspace == 'cmyk'
+
+
 def test_get_depth(fx_asset):
     """Gets the image depth"""
     with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
@@ -611,25 +638,33 @@ def test_crop_error(fx_asset):
             img.crop(bottom=1, height=2)
 
 
-def test_resize(fx_asset):
-    """Resizes the image."""
+@mark.parametrize(('method'), [
+    ('resize'),
+    ('sample'),
+])
+def test_resize_and_sample(method, fx_asset):
+    """Resizes/Samples the image."""
     with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
         with img.clone() as a:
             assert a.size == (402, 599)
-            a.resize(100, 100)
+            getattr(a, method)(100, 100)
             assert a.size == (100, 100)
         with img.clone() as b:
             assert b.size == (402, 599)
-            b.resize(height=100)
+            getattr(b, method)(height=100)
             assert b.size == (402, 100)
         with img.clone() as c:
             assert c.size == (402, 599)
-            c.resize(width=100)
+            getattr(c, method)(width=100)
             assert c.size == (100, 599)
 
 
 @mark.slow
-def test_resize_gif(tmpdir, fx_asset):
+@mark.parametrize(('method'), [
+    ('resize'),
+    ('sample'),
+])
+def test_resize_and_sample_gif(method, tmpdir, fx_asset):
     with Image(filename=str(fx_asset.join('nocomments-delay-100.gif'))) as img:
         assert len(img.sequence) == 46
         with img.clone() as a:
@@ -637,7 +672,7 @@ def test_resize_gif(tmpdir, fx_asset):
             assert a.sequence[0].delay == 100
             for s in a.sequence:
                 assert s.delay == 100
-            a.resize(175, 98)
+            getattr(a, method)(175, 98)
             a.save(filename=str(tmpdir.join('175_98.gif')))
         with Image(filename=str(tmpdir.join('175_98.gif'))) as a:
             assert len(a.sequence) == 46
@@ -648,7 +683,7 @@ def test_resize_gif(tmpdir, fx_asset):
             assert b.size == (350, 197)
             for s in b.sequence:
                 assert s.delay == 100
-            b.resize(height=100)
+            getattr(b, method)(height=100)
             b.save(filename=str(tmpdir.join('350_100.gif')))
         with Image(filename=str(tmpdir.join('350_100.gif'))) as b:
             assert len(b.sequence) == 46
@@ -659,7 +694,7 @@ def test_resize_gif(tmpdir, fx_asset):
             assert c.size == (350, 197)
             for s in c.sequence:
                 assert s.delay == 100
-            c.resize(width=100)
+            getattr(c, method)(width=100)
             c.save(filename=str(tmpdir.join('100_197.gif')))
         with Image(filename=str(tmpdir.join('100_197.gif'))) as c:
             assert len(c.sequence) == 46
@@ -669,21 +704,25 @@ def test_resize_gif(tmpdir, fx_asset):
     tmpdir.remove()
 
 
-def test_resize_errors(fx_asset):
-    """Resizing errors."""
+@mark.parametrize(('method'), [
+    ('resize'),
+    ('sample'),
+])
+def test_resize_and_sample_errors(method, fx_asset):
+    """Resizing/Sampling errors."""
     with Image(filename=str(fx_asset.join('mona-lisa.jpg'))) as img:
         with raises(TypeError):
-            img.resize(width='100')
+            getattr(img, method)(width='100')
         with raises(TypeError):
-            img.resize(height='100')
+            getattr(img, method)(height='100')
         with raises(ValueError):
-            img.resize(width=0)
+            getattr(img, method)(width=0)
         with raises(ValueError):
-            img.resize(height=0)
+            getattr(img, method)(height=0)
         with raises(ValueError):
-            img.resize(width=-5)
+            getattr(img, method)(width=-5)
         with raises(ValueError):
-            img.resize(height=-5)
+            getattr(img, method)(height=-5)
 
 
 @mark.parametrize(('args', 'kwargs', 'expected_size'), [
@@ -1186,3 +1225,48 @@ def test_histogram(fx_asset):
         assert Color('srgb(0,0,255)') in h
         assert h[Color('srgb(0,255,0)')] == 5000
         assert h[Color('srgb(0,0,255)')] == 5000
+
+
+def test_gaussian_blur(fx_asset, display):
+    with Image(filename=str(fx_asset.join('sasha.jpg'))) as img:
+        before = img[100, 100]
+        img.gaussian_blur(30, 10)
+        after = img[100, 100]
+        assert before != after
+        assert 0.84 <= after.red <= 0.85
+        assert 0.74 <= after.green <= 0.75
+        assert 0.655 <= after.blue < 0.67
+
+
+def test_modulate(fx_asset, display):
+    with Image(filename=str(fx_asset.join('sasha.jpg'))) as img:
+        before = img[100,100]
+        img.modulate(120, 120, 120)
+        after = img[100,100]
+        assert before != after
+        assert 0.98 <= after.red <= 0.99
+        assert 0.98 <= after.green <= 0.99
+        assert 0.96 <= after.blue <= 0.97
+
+
+def test_unsharp_mask(fx_asset, display):
+    with Image(filename=str(fx_asset.join('sasha.jpg'))) as img:
+        before = img[100, 100]
+        img.unsharp_mask(1.1, 1, 0.5, 0.001)
+        after = img[100, 100]
+        assert before != after
+        assert 0.89 <= after.red <= 0.90
+        assert 0.82 <= after.green <= 0.83
+        assert 0.73 <= after.blue < 0.74
+
+
+def test_issue_150(fx_asset, tmpdir):
+    """Should not be terminated with segmentation fault.
+
+    https://github.com/dahlia/wand/issues/150
+
+    """
+    with Image(filename=str(fx_asset.join('tiger_hd-1920x1080.jpg'))) as img:
+        img.format = 'pjpeg'
+        with open(str(tmpdir.join('out.jpg')), 'wb') as f:
+            img.save(file=f)
