@@ -8,6 +8,7 @@
 """
 import ctypes
 import ctypes.util
+import itertools
 import os
 import os.path
 import sys
@@ -84,7 +85,10 @@ def load_library():
 
     """
     tried_paths = []
-    for suffix in '', '-Q16', '-Q8', '-6.Q16':
+    versions = ('', '-Q16', '-Q8', '-6.Q16')
+    options = ('', 'HDRI')
+    combinations = itertools.product(versions, options)
+    for suffix in (version + option for version, option in combinations):
         libwand_path, libmagick_path = find_library(suffix)
         if libwand_path is None or libmagick_path is None:
             continue
@@ -282,6 +286,11 @@ try:
 
     library.MagickSetImageUnits.argtypes = [ctypes.c_void_p, ctypes.c_int]
 
+    library.MagickGetImageColorspace.argtypes = [ctypes.c_void_p]
+    library.MagickGetImageColorspace.restype = ctypes.c_int
+
+    library.MagickSetImageColorspace.argtypes = [ctypes.c_void_p, ctypes.c_int]
+
     library.MagickGetImageDepth.argtypes = [ctypes.c_void_p]
     library.MagickGetImageDepth.restype = ctypes.c_size_t
 
@@ -304,6 +313,9 @@ try:
 
     library.MagickResetImagePage.argtypes = [ctypes.c_void_p, ctypes.c_char_p]
 
+    library.MagickSampleImage.argtypes = [ctypes.c_void_p, ctypes.c_size_t,
+                                          ctypes.c_size_t]
+                                          
     library.MagickResizeImage.argtypes = [ctypes.c_void_p, ctypes.c_size_t,
                                           ctypes.c_size_t, ctypes.c_int,
                                           ctypes.c_double]
@@ -459,6 +471,16 @@ try:
     library.MagickTrimImage.argtypes = [ctypes.c_void_p,
                                         ctypes.c_double]
 
+    library.MagickGaussianBlurImage.argtypes = [ctypes.c_void_p,
+                                                ctypes.c_double,
+                                                ctypes.c_double]
+
+    library.MagickUnsharpMaskImage.argtypes = [ctypes.c_void_p,
+                                               ctypes.c_double,
+                                               ctypes.c_double,
+                                               ctypes.c_double,
+                                               ctypes.c_double]
+
     library.MagickGetNumberImages.argtypes = [ctypes.c_void_p]
     library.MagickGetNumberImages.restype = ctypes.c_size_t
 
@@ -597,6 +619,12 @@ try:
     library.DrawSetFillColor.argtypes = [ctypes.c_void_p,
                                          ctypes.c_void_p]
 
+    library.DrawSetStrokeColor.argtypes = [ctypes.c_void_p, 
+                                           ctypes.c_void_p]
+
+    library.DrawSetStrokeWidth.argtypes = [ctypes.c_void_p, 
+                                           ctypes.c_double]
+
     library.DrawSetTextAlignment.argtypes = [ctypes.c_void_p,
                                              ctypes.c_int]
 
@@ -627,6 +655,12 @@ try:
     library.DrawGetFillColor.argtypes = [ctypes.c_void_p,
                                          ctypes.c_void_p]
 
+    library.DrawGetStrokeColor.argtypes = [ctypes.c_void_p, 
+                                           ctypes.c_void_p]
+
+    library.DrawGetStrokeWidth.argtypes = [ctypes.c_void_p]
+    library.DrawGetStrokeWidth.restype = ctypes.c_double
+
     library.DrawGetFont.argtypes = [ctypes.c_void_p]
     library.DrawGetFont.restype = ctypes.c_char_p
 
@@ -724,6 +758,7 @@ else:
         libc = ctypes.cdll.LoadLibrary('libc.so.6')
     libc.fdopen.argtypes = [ctypes.c_int, ctypes.c_char_p]
     libc.fdopen.restype = ctypes.c_void_p
+    libc.fflush.argtypes = [ctypes.c_void_p]
 
 libc.free.argtypes = [ctypes.c_void_p]
 
